Struct EvaluatedTrial
pub struct EvaluatedTrial {
pub id: u64,
pub values: NullableF64Vec,
pub current_step: u64,
}Expand description
An evaluated trial (mirror of kurobako_core::trial::EvaluatedTrial).
Fields
id: u64values: NullableF64Veccurrent_step: u64Implementations
impl EvaluatedTrial
impl EvaluatedTrial
pub fn single_value(&self) -> Option<f64>
pub fn single_value(&self) -> Option<f64>
The single objective value, if the trial was evaluable.
kurobako sends an empty values for an unevaluable trial and encodes
a non-finite objective as JSON null (which decodes to NaN here); both
become None, i.e. a failed observation invisible to the sampler.